<!-- 点击区县名称展开详情-->
<template>
    <div class="pilot-detail">
        <el-form
            label-position="top"
            label-width="300"
            class="dialog-table-expand"
            v-loading="loading"
            :element-loading-background="loadingColor"
        >
            <el-collapse
                v-model="activeCollapse"
                class="dialog-collapse form-collapse"
            >
                <el-collapse-item name="1">
                    <template slot="title">
                        <span class="collapse-title"> 试点项目基础信息 </span>
                    </template>
                    <el-row>
                        <el-form-item label="项目名称：">
                            <span>{{ unitData.pilotProjectName || '无' }}</span>
                        </el-form-item>
                    </el-row>
                    <el-row>
                        <el-form-item label="试点目标：">
                            <span>{{ unitData.pilotTarget || '无' }}</span>
                        </el-form-item>
                    </el-row>
                    <el-row>
                        <el-form-item label="试点任务：">
                            <span>{{ unitData.taskDetails || '无' }} </span>
                        </el-form-item>
                    </el-row>
                </el-collapse-item>
            </el-collapse>
            <template v-if="unitData.ancPropulsiveStatus">
                <el-row>
                    <el-form-item label="已开展工作：" label-width="300">
                        <span>{{ unitData.propulDetails || '无' }}</span>
                    </el-form-item>
                </el-row>
                <el-row>
                    <el-form-item label="存在问题：" label-width="300">
                        <span>{{ unitData.existingProblems || '无' }}</span>
                    </el-form-item>
                </el-row>
                <el-row>
                    <el-form-item label="下一步工作打算：" label-width="300">
                        <span>{{ unitData.workPlan || '无' }}</span>
                    </el-form-item>
                </el-row>
                <el-row>
                    <el-form-item label="试点成果：" label-width="300">
                        <span
                            v-if="
                                unitData.resultNumList &&
                                unitData.resultNumList.length
                            "
                        >
                            <span
                                >形成制度成果
                                {{ unitData.resultNumList[0].regimeNum || 0 }}
                                个；</span
                            >
                            <span
                                >搭建重要平台
                                {{ unitData.resultNumList[0].platformNum || 0 }}
                                个；</span
                            >
                            <span
                                >上线应用场景
                                {{ unitData.resultNumList[0].appNum || 0 }}
                                个；</span
                            >
                            <span
                                >其他成果
                                {{ unitData.resultNumList[0].otherNum || 0 }}
                                个；</span
                            >
                            <span
                                >共计
                                {{ unitData.resultNumList[0].totalNum || 0 }}
                                个试点成果。</span
                            >
                        </span>
                        <span v-else>无</span>
                    </el-form-item>
                </el-row>
            </template>
            <template v-else-if="!loading && !unitData.ancPropulsiveStatus">
                <div
                    style="
                        text-align: center;
                        margin-top: 40px;
                        font-size: 18px;
                    "
                >
                    项目推进状态待更新。
                </div>
            </template>
        </el-form>
    </div>
</template>

<script>
import utils from '@/utils.js'
import apiList from '@/api/bigScreen/districView.js'
export default {
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            activeCollapse: 1,
            unitData: {},
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            params: {
                id: this.tableOptions.id,
                unitCode: this.tableOptions.code,
            },
        }
    },
    watch: {
        'tableOptions.code': {
            handler: function (newValue) {
                this.params.unitCode = newValue
                this.loadData()
            },
            immediate: true,
        },
        'tableOptions.id': {
            handler: function (newValue) {
                this.params.id = newValue
                this.loadData()
            },
            immediate: true,
        },
    },
    mounted() {},
    methods: {
        loadData() {
            this.loading = true
            let data = this.qs.stringify(this.params)
            apiList.pilotPushDetailforUnit(data, (res) => {
                if (res) {
                    this.unitData = res
                }
                this.loading = false
            })
        },
    },
}
</script>

<style lang='scss'>
.pilot-detail{
    height:70vh;
    overflow: auto;
}
.dialog-collapse{
    .el-collapse-item__header{
        background-color: transparent !important;
    }
}
.dialog-collapse .el-collapse-item__wrap{
    background-color: transparent;  
}

</style>
<style lang='scss' scoped>
/deep/ .form-collapse .collapse-title{
    font-size: 20px;
}
/deep/ .el-form-item__content{
    background-color: #133d7b;
    border-radius: 6px;
    padding: 10px;
    box-sizing: border-box;
    margin-bottom: 20px;

}
/* 设置滚动条的样式 */
    ::-webkit-scrollbar {
        width: 8px !important; //垂直方向上的宽
        height: 8px !important; //水平方向上的宽
    }
    
    /* 滚动槽 */
    ::-webkit-scrollbar-track {
         border-radius: 0px;
        background-color: #01215a !important;
    }
    
    /* 滚动条滑块 */
    ::-webkit-scrollbar-thumb {
        border-radius: 6px;
        background-color: rgba(#fff, 0.1) !important;
    }
    /*滚动条交叉样式*/
    ::-webkit-scrollbar-corner {
        background: #01215a !important;
    }
/deep/.dialog-table-expand{
    .el-form-item__content span{
        color: #c0cddf;
        font-size:20px;
        font-family: SimHei;
    }
    label{
        width: 300px!important;
        font-size:18px;
        color: #97c0ff!important;
        font-family: SimHei;
    }
}
</style>